#!/bin/bash
# This is a script to build a Zenwalk package. Check the Zenwalk homepage: www.zenwalk.org
#
# Software			: googleearth 
# Project homepage 	: http://earth.google.com/index.html
# Source           	: http://dl.google.com/earth/client/current/
#														    	   
# Packager         	: skywatcher (s.skywatcher|AT|gmail|DOT|org, simone antoniucci)
# Last revision		: 2009-02-07
#
# BUILD-ONLY DEPS	: -
# NOTES				: (1) The software appears to be not stable on certain machines (crashing on startup)
#					: (2) The software might cause X session to crash on machines with certain combinations of hardware
#					: (3) Script roughly based on the SlackBuild by Michiel van Wessem 
#					: ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#					:
#					: slackware build script for google-earth
#					: written by (michiel van wessem <bp{k}>) (michiel@slackbuilds.org)
#					:
#					: copyright 2007 michiel van wessem (http://michielvwessem.wordpress.com)
#					: all rights reserved.
#					:
#					: redistribution and use of this script, with or without modification, is
#					: permitted provided that the following conditions are met:
#					:
#					: 1. redistributions of this script must retain the above copyright
#					:    notice, this list of conditions and the following disclaimer.
#					:
#					: this software is provided by the author ''as is'' and any express or implied
#					: warranties, including, but not limited to, the implied warranties of
#					: merchantability and fitness for a particular purpose are disclaimed. in no
#					: event shall the author be liable for any direct, indirect, incidental,
#					: special, exemplary, or consequential damages (including, but not limited to,
#					: procurement of substitute goods or services; loss of use, data, or profits;
#					: or business interruption) however caused and on any theory of liability,
#					: whether in contract, strict liability, or tort (including negligence or
#					: otherwise) arising in any way out of the use of this software, even if
#					: advised of the possibility of such damage.
#					:
#					: thanks to robw810 for the additional code and script cleanups, and danieldk, 
#					: alan_hicks for their comments.
#					:
#					: ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

### Checking for unbound variables
set -u

### Setting main variables
NAME="googleearth"
VERSION="5.0.11337.1968"
ARCH="i686"	# precompiled for i686
CPU="i686"
BUILD=60.1

HOMEPAGE="http://earth.google.com/index.html"
DESCRIPTION="Sat images, maps and Google searches"
SRCLNK="http://dl.google.com/earth/client/current/GoogleEarthLinux.bin"

CWD=`pwd`
PKGDIR=$CWD/$NAME-install
PKG=$NAME-$VERSION-$ARCH-$BUILD
SRCPKG=`echo $SRCLNK | rev | cut -d/ -f1 | rev`

TARGET=$PKGDIR/usr/share/$NAME
ICONDIR=$PKGDIR/usr/share/icons/hicolor/48x48/apps		
URL=http://zenwalk.pinguix.com/user-accounts/skywatcher/$NAME/$VERSION

### Cleaning
rm -rf $PKGDIR
#~ rm -rf $SRCDIR

### Mkdir
mkdir -p $PKGDIR
mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/bin
mkdir -p $PKGDIR/usr/doc/$NAME-$VERSION
mkdir -p $PKGDIR/usr/src/$NAME-$VERSION
mkdir -p $TARGET
mkdir -p $PKGDIR/usr/share/applications
mkdir -p $PKGDIR/usr/share/mime
mkdir -p $ICONDIR

### Checking if source is present. If it's not, download it
if [ -f $SRCPKG ]; then
	echo "Source file is already present, no need to download it";
else
 	echo "Downloading source..."
	wget -c -nv $SRCLNK
fi

### Opening installer and extracting data
sh $SRCPKG --noexec --target $TARGET
cd $TARGET
tar xfv $NAME-data.tar && rm -f $NAME-data.tar || exit 1
tar xfv $NAME-linux-x86.tar && rm -f $NAME-linux-x86.tar || exit 1

### Moving and linking executable
cat $TARGET/bin/$NAME > $TARGET/$NAME && rm -fr $TARGET/bin || exit 1
cd $PKGDIR/usr/bin; ln -s ../share/$NAME/$NAME $NAME || exit 1

### Adding info on data folder for the executable to find it
cat $TARGET/$NAME | sed '/# Set the home/a\GOOGLEEARTH_DATA_PATH=/usr/share/googleearth/' > $TARGET/$NAME || exit 1

### Stripping binaries
cd $PKGDIR
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "current ar archive" | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

### Docs, man, info
cd $TARGET
#mv $TARGET/EULA* $PKGDIR/usr/doc/$NAME-$VERSION || exit 1
mv $TARGET/README.linux $PKGDIR/usr/doc/$NAME-$VERSION || exit 1

### Adding build-file to the package
cp -a $CWD/$0 $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh
chmod a+x $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh

### Slack-desc 
#    |-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc << EOF
$NAME: $NAME - $DESCRIPTION
$NAME:  
$NAME: Google Earth combines the power of Google Search with satellite 
$NAME: imagery, maps, terrain and 3D buildings to put the world's
$NAME: geographic information at your fingertips.				      
$NAME: 
$NAME: (NOTE: the software might cause X session to crash on machines 
$NAME: with certain combinations of hardware) 
$NAME:
$NAME: 
$NAME: $HOMEPAGE
EOF

# Desktop entry 
cat > $PKGDIR/usr/share/applications/$NAME.desktop << EOF
[Desktop Entry]
Encoding=UTF-8
Name=Google Earth
GenericName=3D planet viewer
Comment=Explore, search and discover the planet
Exec=googleearth %f
Terminal=false
MultipleArgs=false
Type=Application
Icon=googleearth
Categories=Application;Network
MimeType=application/vnd.google-earth.kml+xml;application/vnd.google-earth.kmz;application/earthviewer;application/keyhole
EOF

# Mime types
cat > $PKGDIR/usr/share/mime/$NAME-mimetypes.xml << EOF
<?xml version="1.0"?>
<mime-info xmlns='http://www.freedesktop.org/standards/shared-mime-info'>
  <mime-type type="application/vnd.google-earth.kml+xml">
    <comment>Keyhole Markup Language data</comment>
    <glob pattern="*.kml"/>
  </mime-type>

  <mime-type type="application/vnd.google-earth.kmz">
    <comment>Keyhole Markup Language archive</comment>
    <glob pattern="*.kmz"/>
  </mime-type>

  <mime-type type="application/keyhole">
    <comment>Keyhole Markup Language data</comment>
  </mime-type>

  <mime-type type="application/earthviewer">
    <comment>Keyhole Markup Language data</comment>
  </mime-type>
</mime-info>
EOF

### Icon
mv $TARGET/$NAME-icon.png $ICONDIR/$NAME.png || exit 1

### Ownerships and permissions
cd $PKGDIR
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

### Unnedeed stuff
rm -f $TARGET/{preuninstall,setup,postinstall}.sh
rm -rf $TARGET/setup.data
rm -rf $TARGET/linux
#rm -f $TARGET/$NAME.xpm

### Doinstall
cat > $PKGDIR/install/doinst.sh << EOF
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q /usr/share/applications >/dev/null 2>&1
fi

if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database /usr/share/mime >/dev/null 2>&1
fi
EOF

### Making the package
makepkg -l y -c n $CWD/$PKG.tgz

cd $CWD

### md5
md5sum $PKG.tgz > $PKG.md5

### dep
#~ depfinder $PKG.tgz > $PKG.dep
echo "glibc,xcb,xorg-libs" > $PKG.dep

### txt
cat $PKGDIR/install/slack-desc > $PKG.txt

### src
rm -fr $PKG.src
for link in $URL/$0 $SRCLNK
	do echo $link >> $PKG.src
done

### Cleaning
rm -rf $PKGDIR

#Done. Ciao!
